<template>
  <div class="divide-y divide-gray-900/10 rounded border border-gray-900/10">
    <LinksOptionCollapse>
      <template #button>
        <div class="flex items-center text-gray-700">
          <GearRegularIcon class="mr-3 size-5 fill-current" />
          <span>{{ $t("app.links.form.sections.settings") }}</span>
        </div>
      </template>
      <template #default>
        <div class="grid grid-cols-1 gap-4 p-4 md:grid-cols-2">
          <FormInput
            id="code"
            :errors="errors.code"
          >
            <FormLabel>{{ $t("app.links.form.code") }}</FormLabel>
            <FormText
              v-model="form.code"
              name="code"
            />
          </FormInput>
          <FormInput
            id="domain"
            :errors="errors.domain_id"
          >
            <FormLabel>{{ $t("app.links.form.domain") }}</FormLabel>
            <FormSelect
              v-model="form.domain_id"
              :options="domains"
              index="id"
              label="domain"
              name="domain"
            />
          </FormInput>
        </div>
      </template>
    </LinksOptionCollapse>
    <LinksOptionCollapse>
      <template #button>
        <div class="flex items-center text-gray-700">
          <KeyRegularIcon class="mr-3 size-5 fill-current" />
          <span>{{ $t("app.links.form.sections.restrictions") }}</span>
        </div>
      </template>
      <template #default>
        <div class="grid grid-cols-1 gap-4 p-4 md:grid-cols-2">
          <FormInput
            id="password"
            :errors="errors.password"
          >
            <FormLabel>{{ $t("app.links.form.password") }}</FormLabel>
            <FormText
              :model-value="form.has_password ? '******' : ''"
              autocomplete="off"
              name="password"
              type="password"
              @update:model-value="form.password = $event !== '********' ? $event : ''"
            />
          </FormInput>
          <FormInput
            id="expires_at"
            :errors="errors.expires_at"
          >
            <FormLabel>{{ $t("app.links.form.expires_at") }}</FormLabel>
            <FormDate
              v-model="form.expires_at"
              name="expires_at"
              time
            />
          </FormInput>
        </div>
      </template>
    </LinksOptionCollapse>
    <LinksOptionCollapse>
      <template #button>
        <div class="flex items-center text-gray-700">
          <GlobeRegularIcon class="mr-3 size-5 fill-current" />
          <span>{{ $t("app.links.form.sections.seo") }}</span>
        </div>
      </template>
      <template #default>
        <div class="grid grid-cols-1 gap-4 p-4">
          <FormInput
            id="title"
            :errors="errors.title"
          >
            <FormLabel>{{ $t("app.links.form.title") }}</FormLabel>
            <FormText
              v-model="form.title"
              name="title"
            />
          </FormInput>
          <FormInput
            id="tags"
            :errors="errors.tags"
          >
            <FormLabel>{{ $t("app.links.form.tags") }}</FormLabel>
            <FormTags v-model="form.tags" />
          </FormInput>
          <FormInput
            id="description"
            :errors="errors.description"
          >
            <FormLabel>{{ $t("app.links.form.description") }}</FormLabel>
            <FormText
              v-model="form.description"
              name="description"
            />
          </FormInput>
        </div>
      </template>
    </LinksOptionCollapse>
  </div>
</template>

<script lang="ts" setup>
import type { Link, LinkCreate, LinkUpdate } from "@/js/contexts/shared/models/Link";
import FormLabel from "@/js/contexts/form/ui/components/FormLabel.vue";
import FormInput from "@/js/contexts/form/ui/components/FormInput.vue";
import FormText from "@/js/contexts/form/ui/components/FormText.vue";
import type { ModelRef } from "vue";
import FormDate from "@/js/contexts/form/ui/components/FormDate.vue";
import FormTags from "@/js/contexts/form/ui/components/FormTags.vue";
import LinksOptionCollapse from "@/js/contexts/links/ui/components/LinksOptionCollapse.vue";
import GearRegularIcon from "@/svg/icons/gear-regular.svg?component";
import KeyRegularIcon from "@/svg/icons/key-regular.svg?component";
import GlobeRegularIcon from "@/svg/icons/globe-regular.svg?component";
import FormSelect from "@/js/contexts/form/ui/components/FormSelect.vue";
import useFetch from "@/js/contexts/shared/composables/useFetch";
import type { Domain } from "@/js/contexts/shared/models/Domain";

defineProps<{
  errors: Partial<Record<keyof LinkCreate | keyof LinkUpdate, string[]>>;
}>();

const form = defineModel<LinkCreate | LinkUpdate>() as ModelRef<Link & { password?: string }>;

const domains = ref<Domain[]>([]);
const domainsFetch = useFetch("/api/links/domains");

onMounted(() => {
  domainsFetch.get<{ data: Domain[] }>().then((response) => (domains.value = response.data.data));
});
</script>
